/*
 * Copyright (c) 1991-2023 by STEP Tools Inc. 
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and
 * its documentation is hereby granted, provided that this copyright
 * notice and license appear on all copies of the software.
 * 
 * STEP TOOLS MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE
 * SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING
 * BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, OR NON-INFRINGEMENT. STEP TOOLS
 * SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A
 * RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS
 * DERIVATIVES.
 *
 * Author: David Loffredo (loffredo@steptools.com)
 */


#include <stp_schema.h>
#include "toolpath.h"

void ToolpathMaker::CoolantOn() 
{
    if (!f_design) return;
    if (!current_coolant) return;

    end_move();	    // Coolant change forces a new toolpath

    current_coolant = 1; 
}

void ToolpathMaker::CoolantOff()	
{ 
    if (!f_design) return;
    if (!current_coolant && !current_mist) return;

    end_move();	    // Coolant change forces a new toolpath

    current_coolant = 0; 
    current_mist = 0; 
}

void ToolpathMaker::CoolantMist()	
{ 
    if (!f_design) return;
    if (!current_mist) return;

    end_move();	    // Coolant change forces a new toolpath

    current_mist = 1; 
}


// Coolant state is handled as properties on a machining_functions
// object.  Other machine state properties that can go on this too,
// but we do not bother with them yet.
// 
stp_machining_functions * ToolpathMaker::make_mfunc()
{
    // No change in feeds/speeds?
    if (current_mfunc &&
	current_coolant == current_mfunc-> is_coolant &&
	current_mist    == current_mfunc-> is_mist)
    {
	return current_mfunc-> mfunc_id;
    }
    
    // Look for an existing mfunc record for this particular
    // feed/speed combination.
    mfuncdef * t = all_mfuncs;
    while (t) {
	if ((current_coolant == t-> is_coolant) &&
	    (current_mist    == t-> is_mist))
	{
	    current_mfunc = t;
	    return t-> mfunc_id;
	}
	t = t-> next_mfunc;
    }

    // No match, create a new mfunc for this feed/speed
    t = new mfuncdef;
    t-> is_coolant = current_coolant;
    t-> is_mist    = current_mist;
    t-> next_mfunc = all_mfuncs;
    all_mfuncs = t;
    current_mfunc = t;

    t-> mfunc_id = pnewIn(f_design) stp_machining_functions;
    t-> mfunc_id-> name ("");
    t-> mfunc_id-> description ("milling");
    t-> mfunc_id-> consequence ("");
    t-> mfunc_id-> purpose ("");

    // Coolant 
    make_action_property (
	"coolant", t-> mfunc_id, 
	make_string_rep (current_coolant? "coolant on": "coolant off")
	);

    // Mist 
    make_action_property (
	"mist", t-> mfunc_id, 
	make_string_rep (current_mist? "mist on": "mist off")
	);

    // Through Spindle -- off for now
    make_action_property (
	"through spindle coolant", t-> mfunc_id, 
	make_string_rep ("through spindle coolant off")
	);

    // Chip Removal -- off for now
    make_action_property (
	"chip removal", t-> mfunc_id, 
	make_string_rep ("chip removal off")
	);

    return t-> mfunc_id;
}

